@@ -10,7 +10,7 @@
 
 	rc = real_dup(fd);
 	save_errno = errno;
-	pseudo_debug(2, "dup: %d->%d\n", fd, rc);
+	pseudo_debug(PDBGF_CLIENT, "dup: %d->%d\n", fd, rc);
 	pseudo_client_op(OP_DUP, 0, fd, rc, 0, 0);
 
 	errno = save_errno;
